use crate::command::{PleaseConfig, PleaseProjectConfig};

pub mod drone;

pub fn get_from_environment() -> PleaseConfig {
    let env = detect_environment();

    match env {
        ExecutionEnvironment::Local => PleaseConfig {
            project: None,
            settings: None,
        },
        ExecutionEnvironment::Drone => PleaseConfig {
            project: Some(PleaseProjectConfig {
                owner: Some(
                    std::env::var("DRONE_REPO_OWNER").expect("DRONE_REPO_OWNER to be present"),
                ),
                repository: Some(
                    std::env::var("DRONE_REPO_NAME").expect("DRONE_REPO_NAME to be present"),
                ),
            }),
            settings: None,
        },
    }
}

pub fn detect_environment() -> ExecutionEnvironment {
    if std::env::var("DRONE").is_ok() {
        return ExecutionEnvironment::Drone;
    }

    ExecutionEnvironment::Local
}

pub enum ExecutionEnvironment {
    Local,
    Drone,
}
